@@ -27,31 +27,27 @@
  * 02110-1301 USA
 	
 */
-
+/*******************************************************************************/
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-
+/*******************************************************************************/
 #include <stdio.h>
 #include <unistd.h>
-
 #include <glib.h>
-
 #include <hildon-home-plugin/hildon-home-plugin-interface.h>
 #include "weather-home.h"
-
 #include <unistd.h>
 #include "weather-home_hash.h"
-
+/*******************************************************************************/
 /* main struct */
 OMWeatherApp	*app = NULL;
-
+/*******************************************************************************/
 /* Translate  temperature Celsius to Farenhait */
 int c2f(int temp){
     return (temp * 1.8f ) + 32;
 }
-
-
+/*******************************************************************************/
 /* Set font size. Usually on label widget */
 void set_font_size(GtkWidget *widget, char font_size){
     PangoFontDescription *pfd = NULL;
@@ -63,7 +59,7 @@ void set_font_size(GtkWidget *widget, char font_size){
     gtk_widget_modify_font(GTK_WIDGET(widget), pfd);   /* this function is leaking */
     pango_font_description_free(pfd);
 }
-
+/*******************************************************************************/
 static gboolean enter_button(GtkWidget *widget,
         			GdkEventCrossing *event){
     GtkButton	*button;
@@ -75,7 +71,7 @@ static gboolean enter_button(GtkWidget *widget,
     gtk_button_leave(button);
     return FALSE;
 }
-
+/*******************************************************************************/
 /* Change station to previos at main display */
 static gboolean change_station_prev(GtkWidget *widget,
                     		    GdkEvent *event,
@@ -114,7 +110,7 @@ static gboolean change_station_prev(GtkWidget *widget,
     }
     return TRUE;
 }
-
+/*******************************************************************************/
 /* Change station to next at main display */
 static gboolean change_station_next(GtkWidget *widget,
                     		    GdkEvent *event,
@@ -152,6 +148,7 @@ static gboolean change_station_next(GtkWidget *widget,
     }
     return TRUE;
 }
+/*******************************************************************************/
 /* Set default value */
 void weather_buttons_init(void){
     int i;
@@ -165,29 +162,33 @@ void weather_buttons_init(void){
     }
     memset(&weather_current_day, 0, sizeof(weather_day));
 }
-
-
+/*******************************************************************************/
 /* Error Window */
 void station_error_window(void){
    hildon_banner_show_information(app->main_window,
 				    NULL,
 				    _("Wrong station code \nor ZIP code!!!"));
 }
-
+/*******************************************************************************/
 /* Fill buttons data */
 void weather_buttons_fill(gboolean check_error){
-    int		i, offset = 0, count_day;
+    int		i, j = 0, k = 0, offset = 0, count_day;
     gchar	buffer[2048], buffer_icon[2048];
     time_t	current_day,current_time, last_day = 0;
+    long int    diff_time;
     struct tm	*tm;
     gboolean	flag_last_day = FALSE, error_station_code = FALSE;
     GSList	*tmplist = NULL;
     struct weather_station *ws = NULL;
-    int		temp_hi,temp_hi_now,temp_low;
+    int		temp_hi = 0, temp_low = 0, temp_current = 0;
     char	font_size;
     gint	icon_size;
     gchar	*tmp_station_name;
+    time_t 	utc_time;
 
+#ifdef PC_EMULATOR
+    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
+#endif
 /* Check main widget */
     if (!app->top_widget)
 	return;
@@ -207,8 +208,6 @@ void weather_buttons_fill(gboolean check_error){
 	    icon_size = 32;
 	break;
     }
-    
-
 /* Init weather buttons */
     weather_buttons_init();
     count_day = parse_weather_com_xml();
@@ -218,112 +217,175 @@ void weather_buttons_fill(gboolean check_error){
 	    fprintf(stderr, _("Error in xml file\n"));
 	    error_station_code = TRUE;
 	} /* Error in xml file */
+/* Clear daytime elments in queue of timer */
+    remove_daytime_event();
 /* get current day */  
-    current_time = current_day = time(NULL);
+    current_time = time(NULL);
+    utc_time = mktime(gmtime(&current_time));
+    diff_time = utc_time-current_time + weather_days[0].zone;
+    current_time = current_day = utc_time + weather_days[0].zone;
+    
     tm = localtime(&current_day);
     tm->tm_sec = 0; tm->tm_min = 0; tm->tm_hour = 0;
     current_day = mktime(tm);
-/* Search day of saving xml near current day */
-    while( (offset < Max_count_weather_day) &&
-	    (current_day > weather_days[offset].date_time) &&
-	    (offset<count_day) )
-	offset ++;
-    for(i = 0; i < app->days_to_show; i++, offset++){
-     /* If it first button add to evenet time change between nigth and day */
-	if((offset < count_day ) &&
-	   (current_day == weather_days[offset].date_time)){
-	    if(current_time < weather_days[offset].day.begin_time)
-		time_event_add(weather_days[offset].day.begin_time,DAYTIMEEVENT);
-	    if(current_time < weather_days[offset].night.begin_time)  
-		time_event_add(weather_days[offset].night.begin_time,DAYTIMEEVENT);
-	}
-    /* Time event add to event list */
-	if( (offset < count_day) &&
-	    (current_day < weather_days[offset].date_time) ){
-	    time_event_add(weather_days[offset].date_time,DAYTIMEEVENT);  /* Add time event  to list */	  
-	    last_day = weather_days[offset].date_time;	  
-	}      
-	if(offset < count_day){
-     /* Prepare temperature value to show on display */
-	    temp_hi_now = atoi(weather_current_day.day.temp); 
-	    temp_hi = atoi(weather_days[offset].hi_temp);     
-	    temp_low = atoi(weather_days[offset].low_temp);     
-	    if(app->temperature_units == FAHRENHEIT ){
-		temp_hi_now = c2f(temp_hi_now);
-		temp_hi = c2f(temp_hi);
-		temp_low = c2f(temp_low);
-	    }  
-     /* Show current weather or forecast */
-	    if( (i==0) && 
-		(weather_current_day.date_time>(current_time-OFFSET_CURRENT_WEATHER*3600)) &&
-                (weather_current_day.date_time<(current_time+OFFSET_CURRENT_WEATHER*3600))){
-      /* Add to evenet time change between current weather and forecast */
-		time_event_add((weather_current_day.date_time+OFFSET_CURRENT_WEATHER*3600),DAYTIMEEVENT);
-      /* Show current weather bold fonts */
-		sprintf(buffer,"<span weight=\"bold\" foreground='#%02x%02x%02x'>%s\n%i\302\260\n</span>",
-            	    app->font_color.red >> 8, app->font_color.green >> 8, app->font_color.blue >> 8,
-            	    weather_days[offset].dayshname, temp_hi_now);
-		sprintf(buffer_icon,"%s%i.png",path_large_icon,weather_current_day.day.icon);
-	    }		
-    	    else{
-      /* Show forecast */
-		if((offset < count_day) &&
-		   (current_day == weather_days[offset].date_time)){
-       /* First icon - night(morning) or day or night (evening) */     
-		    if(current_time<weather_days[offset].day.begin_time){  
-    			sprintf(buffer_icon,"%s%i.png",path_large_icon,weather_days[offset].night.icon);
-	 /* Show All temperatures */
-    		    sprintf(buffer,"<span foreground='#%02x%02x%02x'>%s\n%i\302\260\n%i\302\260</span>",
-            		app->font_color.red >> 8, app->font_color.green >> 8, app->font_color.blue >> 8,
-            		weather_days[offset].dayshname, temp_low, temp_hi);
-		    } 
+
+    offset = (int)( abs( (current_day - weather_days[0].date_time) / (24 * 60 * 60) ) );
+    (app->separate) ? (k = 1) : (k = 0); /* add one more day if data is separate */
+    for(i = 0; i < app->days_to_show; i++){
+	if( i + offset < Max_count_weather_day + k ){
+	    if(i == 0 || (app->separate && i == 1)){	/* first day */
+		/* repeat the same data in second button for first day if data is separate */
+		(app->separate && i == 1) ? (j = -1) : (j = 0); 
+		/* prepare temperature for first day */
+		if(!strcmp(weather_days[i + offset + j].hi_temp, "N/A"))
+		    temp_hi = INT_MAX;
+		else
+		    temp_hi = atoi(weather_days[i + offset + j].hi_temp);
+		if(!strcmp(weather_days[i + offset + j].low_temp, "N/A"))
+        	    temp_low = INT_MAX;
+		else
+		    temp_low = atoi(weather_days[i + offset + j].low_temp);
+		if(!strcmp(weather_current_day.day.temp, "N/A"))
+		    temp_current = INT_MAX;
+		else
+		    temp_current = atoi(weather_current_day.day.temp);
+        	if(app->temperature_units == FAHRENHEIT){
+		    if(temp_hi != INT_MAX)
+            		temp_hi = c2f(temp_hi);
+		    if(temp_low != INT_MAX)
+            		temp_low = c2f(temp_low);
+		    if(temp_current != INT_MAX)
+			temp_current = c2f(temp_current);
+        	}
+		
+		current_time = utc_time + weather_days[i + offset + j].zone;
+		
+		/* add events for first day */
+		if(current_time < weather_days[i + offset + j].day.begin_time )
+    		    time_event_add(weather_days[i + offset + j].day.begin_time - diff_time, DAYTIMEEVENT);
+		if(current_time < weather_days[i + offset + j].night.begin_time )
+		    time_event_add(weather_days[i + offset + j].night.begin_time - diff_time, DAYTIMEEVENT);		
+		/* check weather data for actuality */
+		if( (weather_current_day.date_time > (current_time - app->data_valid_interval - 3600)) &&
+            	    (weather_current_day.date_time < (current_time + app->data_valid_interval + 3600)) && i == 0){
+		    time_event_add(weather_current_day.date_time + app->data_valid_interval - diff_time + 3600, DAYTIMEEVENT);
+		    if(temp_current == INT_MAX)
+			sprintf(buffer,
+				"<span weight=\"bold\" foreground='#%02x%02x%02x'>%s\n%s\302\260\n</span>",
+				app->font_color.red >> 8,
+				app->font_color.green >> 8,
+				app->font_color.blue >> 8,
+				(app->separate) ? (_("Now")) : (weather_days[i + offset + j].dayshname),
+				_("N/A") );
 		    else
-			if(current_time<weather_days[offset].night.begin_time){
-    			    sprintf(buffer_icon,"%s%i.png",path_large_icon,weather_days[offset].day.icon);    
-       /* Show All temperatures */
-			    sprintf(buffer,"<span foreground='#%02x%02x%02x'>%s\n%i\302\260\n%i\302\260</span>",
-            			app->font_color.red >> 8, app->font_color.green >> 8, app->font_color.blue >> 8,
-            			weather_days[offset].dayshname, temp_low, temp_hi);
-			}		
-			else{
-    			    sprintf(buffer_icon,"%s%i.png",path_large_icon,weather_days[offset].night.icon);
-	 /* Show only night temperature */
-    			    sprintf(buffer,"<span foreground='#%02x%02x%02x'>%s\n%i\302\260\n</span>",
-            			app->font_color.red >> 8, app->font_color.green >> 8, app->font_color.blue >> 8,
-            			weather_days[offset].dayshname, temp_low);
+			sprintf(buffer,
+				"<span weight=\"bold\" foreground='#%02x%02x%02x'>%s\n%i\302\260\n</span>",
+				app->font_color.red >> 8,
+				app->font_color.green >> 8,
+				app->font_color.blue >> 8,
+				(app->separate) ? (_("Now")) : (weather_days[i + offset + j].dayshname),
+				temp_current );
+		    sprintf(buffer_icon, "%s%i.png", path_large_icon, weather_current_day.day.icon);
+		}
+		else{ /* if current data is not actual */
+		    if(i == 0 && app->separate){ /* if current data isn't actual and first day */
+		    	sprintf(buffer, "<span foreground='#%02x%02x%02x'>%s\n%s\302\260</span>",
+				    app->font_color.red >> 8,
+				    app->font_color.green >> 8,
+				    app->font_color.blue >> 8,
+				    _("Now"),
+				    _("N/A"));
+			sprintf(buffer_icon, "%s48.png", path_large_icon);
+		    }
+		    else{ /* if first day and not separate data */
+			/* if current time is night show night icon */
+			if(current_time < weather_days[i + offset + j].day.begin_time)
+			    sprintf(buffer_icon, "%s%i.png", path_large_icon, weather_days[i + offset + j].night.icon);
+			else{/* if current time is day show day icon */
+			    if(current_time < weather_days[i + offset + j].night.begin_time)
+				sprintf(buffer_icon, "%s%i.png", path_large_icon, weather_days[i + offset + j].day.icon);
+			    else
+				sprintf(buffer_icon, "%s%i.png", path_large_icon, weather_days[i + offset + j].night.icon);
 			}
+			/* show temperature */
+			if(app->swap_hi_low_temperature)
+			    swap_temperature(&temp_hi, &temp_low);
+			sprintf(buffer,
+				"<span foreground='#%02x%02x%02x'>%s\n",
+				app->font_color.red >> 8,
+				app->font_color.green >> 8,
+				app->font_color.blue >> 8,
+				weather_days[i + offset + j].dayshname);
+			if(temp_low == INT_MAX)
+			    sprintf(buffer + strlen(buffer), "%s\302\260\n", _("N/A") );
+			else
+			    sprintf(buffer + strlen(buffer), "%i\302\260\n", temp_low );
+			if(temp_hi == INT_MAX)
+			    sprintf(buffer + strlen(buffer), "%s\302\260", _("N/A") );
+			else
+			    sprintf(buffer + strlen(buffer), "%i\302\260", temp_hi );
+			strcat(buffer, "</span>");
+		    }
 		}
-		else{
-       /* Create output string for full time of day (day and night)*/
-		    sprintf(buffer,"<span foreground='#%02x%02x%02x'>%s\n%i\302\260\n%i\302\260</span>",
-            		app->font_color.red >> 8, app->font_color.green >> 8, app->font_color.blue >> 8,
-            		weather_days[offset].dayshname, temp_low, temp_hi);
-		    sprintf(buffer_icon,"%s%i.png",path_large_icon,weather_days[offset].day.icon);
-		}		    
 	    }
+	    else{ /* other days, from two and to app->days_to_show */
+	    	if(!strcmp(weather_days[i + offset + j].hi_temp, "N/A"))
+		    temp_hi = INT_MAX;
+		else
+		    temp_hi = atoi(weather_days[i + offset + j].hi_temp);
+		if(!strcmp(weather_days[i + offset + j].low_temp, "N/A"))
+        	    temp_low = INT_MAX;
+		else
+		    temp_low = atoi(weather_days[i + offset + j].low_temp);
+        	if(app->temperature_units == FAHRENHEIT){
+		    if(temp_hi != INT_MAX)
+            		temp_hi = c2f(temp_hi);
+		    if(temp_low != INT_MAX)
+            		temp_low = c2f(temp_low);
+        	}
+	        time_event_add(weather_days[i + offset + j].date_time, DAYTIMEEVENT);
+                last_day = weather_days[i + offset + j].date_time;
+		if(app->swap_hi_low_temperature)
+		    swap_temperature(&temp_hi, &temp_low);
+		sprintf(buffer_icon, "%s%i.png", path_large_icon, weather_days[i + offset + j].day.icon);
+		sprintf(buffer,
+			"<span foreground='#%02x%02x%02x'>%s\n",
+			app->font_color.red >> 8,
+			app->font_color.green >> 8,
+			app->font_color.blue >> 8,
+			weather_days[i + offset + j].dayshname);
+		if(temp_low == INT_MAX)
+		    sprintf(buffer + strlen(buffer), "%s\302\260\n", _("N/A") );
+		else
+		    sprintf(buffer + strlen(buffer), "%i\302\260\n", temp_low );
+		if(temp_hi == INT_MAX)
+		    sprintf(buffer + strlen(buffer), "%s\302\260", _("N/A") );
+		else
+		    sprintf(buffer + strlen(buffer), "%i\302\260", temp_hi );
+		strcat(buffer, "</span>");		
+	    }
+	    boxs_offset[i] = i + offset + j;
 	}
-	else{
-     /* Show N/A */
-	    sprintf(buffer,"<span foreground='#%02x%02x%02x'>%s\n%s\302\260\n%s\302\260</span>",
-            	app->font_color.red >> 8, app->font_color.green >> 8, app->font_color.blue >> 8,
-		_("N/A"), _("N/A"), _("N/A"));
-	    sprintf(buffer_icon,"%s48.png",path_large_icon);
-     /* Add time event to list for next day after last day in xml file */
+	else{ /* Show N/A for all others day buttons when it not inside range */
+	    sprintf(buffer, "<span foreground='#%02x%02x%02x'>%s\n%s\302\260\n%s\302\260</span>",
+			app->font_color.red >> 8,
+			app->font_color.green >> 8,
+			app->font_color.blue >> 8,
+			_("N/A"), _("N/A"), _("N/A"));
+	    sprintf(buffer_icon, "%s48.png", path_large_icon);
 	    if(!flag_last_day && last_day){
-		time_event_add(last_day + 24 * 60 * 60, DAYTIMEEVENT);  /* Add time event  to list */	  
+		time_event_add(last_day + 24 * 60 * 60, DAYTIMEEVENT);
 		flag_last_day = TRUE;
-	    } 
-	}
-     /* Write offset in wetaher data for this button */
-        if(offset < count_day)
-	    boxs_offset[i] = offset;
-	else 
+	    }
 	    boxs_offset[i] = Max_count_weather_day;
-     /* Prepare butons for view */   
+    	}
 	app->buttons[i] = create_weather_day_button(buffer, buffer_icon, icon_size, app->transparency, font_size);
-	g_signal_connect(app->buttons[i]->button, "released", G_CALLBACK(weather_window_popup_show), NULL);
-	g_signal_connect(app->buttons[i]->button, "enter", G_CALLBACK(enter_button), NULL); 
-    }/* for */
+	if(app->buttons[i]){
+	    g_signal_connect(app->buttons[i]->button, "released", G_CALLBACK(weather_window_popup_show), NULL);
+	    g_signal_connect(app->buttons[i]->button, "enter", G_CALLBACK(enter_button), NULL); 
+	}    
+    }/* end for */
+
     if(g_slist_length(stations_view_list) > 0){
 	tmplist = stations_view_list;
 /* search current station */
@@ -348,7 +410,7 @@ void weather_buttons_fill(gboolean check_error){
     if(error_station_code)
 	station_error_window();
 }
-
+/*******************************************************************************/
 void weather_frame_update(gboolean check){
 
     free_memory(FALSE);
@@ -359,18 +421,17 @@ void weather_frame_update(gboolean check){
     else
 	weather_buttons_fill(FALSE);
 }
-
+/*******************************************************************************/
 /* Get Weather xml file from weather.com */
 void update_weather(void){
     if (app->flag_updating == 0)
 	app->flag_updating = g_timeout_add(100, (GSourceFunc)download_html, NULL);
 }
-
-
+/*******************************************************************************/
 void* hildon_home_applet_lib_initialize(void *state_data, 
 					int *state_size,
 					GtkWidget **widget){
-    osso_context_t *osso;
+    osso_context_t	*osso;
     
     osso = osso_initialize(PACKAGE, VERSION, FALSE, NULL);
     if(!osso){
@@ -395,11 +456,12 @@ void* hildon_home_applet_lib_initialize(void *state_data,
     app->wind_units = METERS_S;
     app->temperature_units = CELSIUS;
     app->dbus_is_initialize = FALSE;
+    app->data_valid_interval = 2 * 3600;
 /* Init gconf. */
     gnome_vfs_init();
     read_config();
 /* Start timer */
-    timer();
+    timer(6000); /* One per secund */
 /* Start main applet */ 
     app->top_widget = gtk_hbox_new(FALSE, 0);
     weather_buttons_fill(FALSE);
@@ -411,8 +473,7 @@ void* hildon_home_applet_lib_initialize(void *state_data,
     (*widget) = app->top_widget;
     return (void*)osso;
 }
-
-
+/*******************************************************************************/
 int hildon_home_applet_lib_save_state(void *raw_data,
 				    void **state_data, 
 				    int *state_size){
@@ -424,19 +485,19 @@ int hildon_home_applet_lib_save_state(void *raw_data,
 	(*state_size) = 0;
     return 1;
 }
-
+/*******************************************************************************/
 void hildon_home_applet_lib_background(void *raw_data){
     #ifdef PC_EMULATOR
         fprintf(stderr, "\nOMWeather applet background\n");
     #endif
 }
-
+/*******************************************************************************/
 void hildon_home_applet_lib_foreground(void *raw_data){
     #ifdef PC_EMULATOR
 	fprintf(stderr, "\nOMWeather applet foreground\n");
     #endif
 }
-
+/*******************************************************************************/
 void hildon_home_applet_lib_deinitialize(void *applet_data){
     osso_context_t *osso;
     gboolean check;
@@ -466,7 +527,7 @@ void hildon_home_applet_lib_deinitialize(void *applet_data){
     /* Deinitialize libosso */
     osso_deinitialize(osso);
 }
-
+/*******************************************************************************/
 GtkWidget* hildon_home_applet_lib_settings(void *applet_data,
 					    GtkWindow *parent){
     #ifdef PC_EMULATOR
@@ -474,6 +535,7 @@ GtkWidget* hildon_home_applet_lib_settings(void *applet_data,
     #endif
     return NULL;
 }
+/*******************************************************************************/
 /* create days panel and station name panel */
 void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* st_name, char f_size){
     gchar	buffer[2048];
@@ -485,6 +547,9 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
 
     int		n, elements, x, y;
 
+#ifdef PC_EMULATOR
+    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
+#endif
 
     if(app->days_to_show % 2)
 	elements = app->days_to_show / 2 + 1;
@@ -570,6 +635,7 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
     }
 /* attach days buttons */
     for(n = 0, x = 0, y = 0; n < app->days_to_show; n++, x++){
+      if (app->buttons[n]){
 	switch(layout){
 	    default:
 	    case ONE_ROW:
@@ -597,6 +663,7 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
 		    gtk_table_attach( (GtkTable*)days_panel, app->buttons[n]->button, 1, 2, x, x + 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 	    break;
 	}
+      }	
     }
 /* attach to main panel header and days panels */
     gtk_table_attach( (GtkTable*)panel, header_panel, 0, 1, 0, 1 ,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
@@ -611,9 +678,8 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
     gtk_container_set_focus_child(GTK_CONTAINER(panel), station_name_btn); 
     if(station_name_btn)
 	g_object_unref(station_name_btn);
-
 }
-
+/*******************************************************************************/
 /* free used memory from OMWeather struct */
 void free_memory(gboolean flag){
     int    i;
@@ -682,24 +748,18 @@ void free_memory(gboolean flag){
 	for(i = 0; i < app->days_to_show; i++)
 	    delete_weather_day_button( TRUE, &(app->buttons[i]) );
 }
-
+/*******************************************************************************/
 WDB* create_weather_day_button(const char *text, const char *icon, const int icon_size, gboolean transparency, char font_size){
 
     WDB	*new_day_button;
+
+#ifdef PC_EMULATOR
+    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
+#endif
     
     new_day_button = g_new0(WDB, 1);
     if(!new_day_button)
 	return NULL;
-    /* create day icon buffer */
-    new_day_button->icon_buffer
-	    = gdk_pixbuf_new_from_file_at_size(icon,
-						icon_size,
-						icon_size, NULL);
-    if(!new_day_button->icon_buffer)
-	return NULL;
-    /* create day icon image from buffer */
-    new_day_button->icon_image = gtk_image_new_from_pixbuf(new_day_button->icon_buffer);
-    g_object_unref(G_OBJECT(new_day_button->icon_buffer));
     /* create day button */
     new_day_button->button = gtk_button_new();
     if(transparency)
@@ -713,14 +773,28 @@ WDB* create_weather_day_button(const char *text, const char *icon, const int ico
     set_font_size(new_day_button->label, font_size);
     /* create day box to contain icon and label */
     new_day_button->box = gtk_hbox_new(FALSE, 0);
+    /* create day icon buffer */
+    new_day_button->icon_buffer
+	    = gdk_pixbuf_new_from_file_at_size(icon,
+						icon_size,
+						icon_size, NULL);
+    if(new_day_button->icon_buffer){
+	/* create day icon image from buffer */
+	new_day_button->icon_image = gtk_image_new_from_pixbuf(new_day_button->icon_buffer);
+	g_object_unref(G_OBJECT(new_day_button->icon_buffer));
+    }
+    else
+    	new_day_button->icon_image = NULL;
+
     /* Packing all to the box */
-    gtk_box_pack_start(GTK_BOX(new_day_button->box), new_day_button->icon_image, FALSE, FALSE, 0);
+    if (new_day_button->icon_buffer)
+	gtk_box_pack_start(GTK_BOX(new_day_button->box), new_day_button->icon_image, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(new_day_button->box), new_day_button->label, FALSE, FALSE, 0);
     gtk_container_add(GTK_CONTAINER(new_day_button->button), new_day_button->box);
     return new_day_button;
 }
-
-void delete_weather_day_button(gboolean after_all_destroy,WDB **day){
+/*******************************************************************************/
+void delete_weather_day_button(gboolean after_all_destroy, WDB **day){
 
     if(after_all_destroy){
 	if(*day){
@@ -751,3 +825,10 @@ void delete_weather_day_button(gboolean after_all_destroy,WDB **day){
 	}
     }
 }
+/*******************************************************************************/
+void swap_temperature(int *hi, int *low){
+    int tmp;
+    
+    tmp = *hi; *hi = *low; *low = tmp;
+}
+/*******************************************************************************/
