@@ -335,7 +335,7 @@ void read_config(void){
     app->update_interval = gconf_client_get_int(gconf_client,
         			    GCONF_KEY_WEATHER_UPDATE_INTERVAL,
 				    NULL);
-    if(app->update_interval < 0 || app->update_interval > 8)
+    if(app->update_interval < 0 || app->update_interval > 24 * 60) /* No more than 24 hours */
 	app->update_interval = 0;
     /* Get Weather font color. */    	
     tmp = gconf_client_get_string(gconf_client,
