@@ -25,9 +25,8 @@
  * License along with this software; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
-	
 */
-
+/*******************************************************************************/
 #include "weather-home_preference.h"
 #if defined (BSD) && !_POSIX_SOURCE
     #include <sys/dir.h>
@@ -37,12 +36,12 @@
     #include <linux/fs.h>
     typedef struct dirent Dirent;
 #endif
+/*******************************************************************************/
 /* Hack for Maemo SDK 2.0 */
 #ifndef DT_DIR
 #define DT_DIR 4
 #endif
-
-
+/*******************************************************************************/
 /* Compare station name */
 gint compare_station(gconstpointer a, gconstpointer b){
     gint result;
@@ -58,8 +57,7 @@ gint compare_station(gconstpointer a, gconstpointer b){
 		    strlen(sca->station_name));
     return result;
 }
-
-
+/*******************************************************************************/
 /* Free memory allocated for stations list */
 void free_list_stations(void){
     static GSList *stations_list_temp = NULL;
@@ -78,7 +76,7 @@ void free_list_stations(void){
 	stations_list_in_state = NULL;
     } 
 }
-
+/*******************************************************************************/
 /* Select item on country combobox */
 void changed_country(void){
     GtkTreeModel *model;
@@ -108,18 +106,19 @@ void changed_country(void){
 	    if(strlen(out_buffer) > 0){
 		if(streq("----------------------------------------------------------------------\n",out_buffer))
     		    flag = (flag == TRUE) ? FALSE : TRUE ;
-		else
+		else{
 		    if(flag == TRUE){
     			if(strcmp("\n",out_buffer) != 0){
     			    sprintf(country_name, "%.38s", out_buffer);
 			    if(streq(gcountry_name, country_name)){
-	    /* Write country code */
+				/* Write country code */
 				country_code[0] = out_buffer[48];
 				country_code[1] = out_buffer[49];	    
 				country_code[2] = 0;
 			    }
 			}
 		    }
+		}
 	    }	
 	}
     }
@@ -153,7 +152,7 @@ void changed_country(void){
     app->current_country = gcountry_name;
     free_list_stations();
 }
-
+/*******************************************************************************/
 /* Select item on state combobox */
 void changed_state(void){
     GtkTreeModel	*model = NULL;
@@ -230,7 +229,7 @@ void changed_state(void){
     }    
     g_free(gstate_name);
 }
-
+/*******************************************************************************/
 /* Select item on station combobox */
 void changed_stations(void){
     struct station_and_weather_code *sc;
@@ -252,7 +251,7 @@ void changed_stations(void){
 	stations_list_temp = g_slist_next(stations_list_temp);
     }
 }
-
+/*******************************************************************************/
 /* Fill station list (tree) */
 void fill_station_list_view(GtkWidget *station_list_view,
 			    GtkListStore *station_list_store){
@@ -275,9 +274,9 @@ void fill_station_list_view(GtkWidget *station_list_view,
 	tmplist = g_slist_next(tmplist);
     }
 }
+/*******************************************************************************/
 /* Rename the station name */
-void 
-weather_window_rename_station(GtkWidget *widget,
+void weather_window_rename_station(GtkWidget *widget,
             			   GdkEvent *event,
                     		   gpointer user_data){
     
@@ -303,13 +302,14 @@ weather_window_rename_station(GtkWidget *widget,
     window_rename_station = gtk_dialog_new_with_buttons(_("Rename Station"),
         						NULL,
 							GTK_DIALOG_MODAL,
-        						GTK_STOCK_OK,
-							GTK_RESPONSE_ACCEPT, NULL);
+							NULL);
 
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window_rename_station)->vbox),
         		    table = gtk_table_new(2, 2, FALSE), TRUE, TRUE, 0);	    
     gtk_dialog_add_button(GTK_DIALOG(window_rename_station),
-        		    GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT);
+        		    _("OK"), GTK_RESPONSE_ACCEPT);
+    gtk_dialog_add_button(GTK_DIALOG(window_rename_station),
+			    _("Cancel"), GTK_RESPONSE_REJECT);
    /* Add Label and Edit */
     gtk_table_attach_defaults(GTK_TABLE(table),
         			label = gtk_label_new(_("Station:")),
@@ -351,7 +351,7 @@ weather_window_rename_station(GtkWidget *widget,
         g_free(station_selected);
     gtk_widget_destroy(window_rename_station);
 }
-
+/*******************************************************************************/
 /* Delete station from list */
 static gboolean weather_delete_station(GtkWidget *widget,
                     		GdkEvent *event,
@@ -440,14 +440,13 @@ static gboolean weather_delete_station(GtkWidget *widget,
         g_free (station_selected);
     return TRUE;
 }
-
+/*******************************************************************************/
 static GtkListStore* create_station_list_store(void){
     GtkListStore *station_list = NULL;
     station_list = gtk_list_store_new(1, G_TYPE_STRING);
     return station_list;
 }
-
-
+/*******************************************************************************/
 static GtkWidget* create_tree_view(GtkListStore * list){
     GtkWidget *tree_view = NULL;
     GtkTreeSelection *list_selection = NULL;
@@ -473,10 +472,11 @@ static GtkWidget* create_tree_view(GtkListStore * list){
 /* return widget to caller */
     return tree_view;
 }
-
+/*******************************************************************************/
 #define ZERO(type, name) type name; memset(&name, 0, sizeof name)
 #define SIG_TIMER_EXPIRATION SIGRTMIN
 #define CLOCK_TYPE CLOCK_MONOTONIC
+/*******************************************************************************/
 struct timespec get_time_stamp(void){
     ZERO(struct timespec, now);
     if(clock_gettime(CLOCK_TYPE, &now) != 0)
@@ -484,7 +484,7 @@ struct timespec get_time_stamp(void){
     fprintf(stderr, "NOW=%ld.%09ld\n", now.tv_sec, now.tv_nsec);
     return now;
 }
-
+/*******************************************************************************/
 void weather_window_add_custom_station(){
     struct weather_station *ws;       /* Temp struct for station */
     GtkWidget *window_add_custom_station;
@@ -494,12 +494,13 @@ void weather_window_add_custom_station(){
 /* Create dialog window */
     window_add_custom_station = gtk_dialog_new_with_buttons(_("Add Custom Station"),
         							NULL, GTK_DIALOG_MODAL,
-        							GTK_STOCK_OK,
-								GTK_RESPONSE_ACCEPT, NULL);
+								NULL);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window_add_custom_station)->vbox),
         		    table = gtk_table_new(4, 2, FALSE), TRUE, TRUE, 0);	    
     gtk_dialog_add_button(GTK_DIALOG(window_add_custom_station),
-        		    GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT);
+        		    _("OK"), GTK_RESPONSE_ACCEPT);
+    gtk_dialog_add_button(GTK_DIALOG(window_add_custom_station),
+			    _("Cancel"), GTK_RESPONSE_REJECT);
 /* Add Custom Station Name  */
     gtk_table_attach_defaults(GTK_TABLE(table),
         			label = gtk_label_new(_("Station name:")),
@@ -548,7 +549,7 @@ void weather_window_add_custom_station(){
     }
     gtk_widget_destroy(window_add_custom_station);
 }
-
+/*******************************************************************************/
 void weather_window_add_station(GtkWidget *widget,
             			GdkEvent *event,
                     		gpointer user_data){
@@ -567,14 +568,15 @@ void weather_window_add_station(GtkWidget *widget,
     window_add_station = gtk_dialog_new_with_buttons(_("Add Station"),
         						NULL,
 							GTK_DIALOG_MODAL,
-        						GTK_STOCK_OK,
-							GTK_RESPONSE_ACCEPT, NULL);
+							NULL);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window_add_station)->vbox),
         		table = gtk_table_new(4, 2, FALSE), TRUE, TRUE, 0);
     gtk_dialog_add_button(GTK_DIALOG(window_add_station),
                     		_("Add Custom Station"), OMW_RESPONSE_ADD_CUSTOM_STATION);
     gtk_dialog_add_button(GTK_DIALOG(window_add_station),
-        			GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT);
+				_("OK"), GTK_RESPONSE_ACCEPT);
+    gtk_dialog_add_button(GTK_DIALOG(window_add_station),
+        			_("Cancel"), GTK_RESPONSE_REJECT);
 /* Add Country */
     gtk_table_attach_defaults(GTK_TABLE(table),
         			label = gtk_label_new(_("Country:")),
@@ -672,7 +674,7 @@ void weather_window_add_station(GtkWidget *widget,
     }
     gtk_widget_destroy(window_add_station); 
 }
-
+/*******************************************************************************/
 /* Main preference window */
 void weather_window_preference(GtkWidget *widget,
 				GdkEvent *event,
@@ -684,6 +686,8 @@ void weather_window_preference(GtkWidget *widget,
 		*table = NULL,
 		*font_color = NULL,
 		*chk_transparency = NULL,
+		*separate_button = NULL,
+		*swap_temperature_button = NULL,
 		*scrolled_window = NULL,
 		*button_add = NULL,
 		*button_del = NULL,
@@ -697,7 +701,9 @@ void weather_window_preference(GtkWidget *widget,
     struct time_update *tu; /* Temporary for time update list */
     static char *temp_string; /* Temporary for the results differnet strdup functions */
     static int result_gtk_dialog_run; /* Temporary for the gtk_dialog_run result */
-   
+    time_t	next_update_time = 0;
+    char	tmp_buff[2048];
+
     not_event = TRUE;
     flag_update_station = FALSE;
     flag_update_icon = FALSE;
@@ -710,14 +716,16 @@ void weather_window_preference(GtkWidget *widget,
     window_config = gtk_dialog_new_with_buttons(_("Other Maemo Weather Settings"),
         				NULL,
 					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-        				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 					NULL);
+    /* add OK button */
+    gtk_dialog_add_button(GTK_DIALOG(window_config),
+	    _("OK"), GTK_RESPONSE_ACCEPT);
     /* add CANCEL button */
     gtk_dialog_add_button(GTK_DIALOG(window_config),
-            GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT);
+            _("Cancel"), GTK_RESPONSE_REJECT);
     /* add Help button */
     gtk_dialog_add_button(GTK_DIALOG(window_config),
-            GTK_STOCK_ABOUT, GTK_RESPONSE_HELP);
+            _("About"), GTK_RESPONSE_HELP);
 /* Create Notebook widget */
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window_config)->vbox),
         	    notebook = gtk_notebook_new(), TRUE, TRUE, 0);
@@ -777,12 +785,12 @@ void weather_window_preference(GtkWidget *widget,
                 	NULL);
 /* Interface tab */
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
-        			table = gtk_table_new(1, 6, FALSE),
+        			table = gtk_table_new(1, 8, FALSE),
         			label = gtk_label_new(_("Interface")));
 /* Days to show */
     app->days_to_show--; /* count down, because combobox items start with 0 */
     gtk_table_attach_defaults(GTK_TABLE(table),	    
-				label = gtk_label_new(_("Days to show:")),
+				label = gtk_label_new(_("Visible items:")),
 				0, 1, 0, 1);
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
@@ -878,6 +886,26 @@ void weather_window_preference(GtkWidget *widget,
     gtk_container_add(GTK_CONTAINER(label),chk_transparency = gtk_check_button_new());
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chk_transparency),
         			    app->transparency);
+    /* Split */
+    gtk_table_attach_defaults(GTK_TABLE(table),	    
+        			label = gtk_label_new(_("Separate current weather data")),
+        			0, 1, 7, 8);
+    gtk_table_attach_defaults(GTK_TABLE(table),	    
+        			label = gtk_alignment_new(0, 0.5, 0.f, 0.f) ,
+        			1, 2, 7, 8);
+    gtk_container_add(GTK_CONTAINER(label), separate_button = gtk_check_button_new());
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(separate_button),
+        			    app->separate);
+    /* Swap temperature */
+    gtk_table_attach_defaults(GTK_TABLE(table),	    
+        			label = gtk_label_new(_("Swap hi/low temperature")),
+        			0, 1, 8, 9);
+    gtk_table_attach_defaults(GTK_TABLE(table),	    
+        			label = gtk_alignment_new(0, 0.5, 0.f, 0.f) ,
+        			1, 2, 8, 9);
+    gtk_container_add(GTK_CONTAINER(label), swap_temperature_button = gtk_check_button_new());
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(swap_temperature_button),
+        			    app->swap_hi_low_temperature);
 /* Units tab */
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         			table = gtk_table_new(1, 3, FALSE),
@@ -907,15 +935,13 @@ void weather_window_preference(GtkWidget *widget,
     gtk_container_add(GTK_CONTAINER(label), units = gtk_combo_box_new_text());
     gtk_combo_box_append_text(GTK_COMBO_BOX(units), _("Meters"));
     gtk_combo_box_append_text(GTK_COMBO_BOX(units), _("Kilometers"));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(units), _("Miles (International)"));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(units), _("Miles (Imperial)"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(units), _("Miles"));
     gtk_combo_box_append_text(GTK_COMBO_BOX(units), _("Miles (Sea)"));
     switch(app->distance_units){
 	default:
 	case METERS:			gtk_combo_box_set_active(GTK_COMBO_BOX(units), METERS);break;
 	case KILOMETERS:	 	gtk_combo_box_set_active(GTK_COMBO_BOX(units), KILOMETERS);break;
-	case INTERNATIONAL_MILES:	gtk_combo_box_set_active(GTK_COMBO_BOX(units), INTERNATIONAL_MILES);break;
-	case IMPERIAL_MILES:		gtk_combo_box_set_active(GTK_COMBO_BOX(units), IMPERIAL_MILES);break;
+	case MILES:			gtk_combo_box_set_active(GTK_COMBO_BOX(units), MILES);break;
 	case SEA_MILES:			 gtk_combo_box_set_active(GTK_COMBO_BOX(units), SEA_MILES);break;
     }    
 /* Wind units */
@@ -943,15 +969,48 @@ void weather_window_preference(GtkWidget *widget,
     }    
 /* Update tab */
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
-        			table = gtk_table_new(1, 2, FALSE),
+        			table = gtk_table_new(3, 2, FALSE),
         			label = gtk_label_new(_("Update")));
     gtk_table_attach_defaults(GTK_TABLE(table),
-        			label = gtk_label_new(_("Updating of weather data:")),
+        			label = gtk_label_new(_("Valid time for current weather:")),
         			0, 1, 0, 1);
     gtk_table_attach_defaults(GTK_TABLE(table),
         			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
         			1, 2, 0, 1);
+    gtk_container_add(GTK_CONTAINER(label), valid_time_list = gtk_combo_box_new_text());
+    gtk_combo_box_append_text(GTK_COMBO_BOX(valid_time_list), _("1 hour"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(valid_time_list), _("2 hours"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(valid_time_list), _("4 hours"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(valid_time_list), _("8 hours"));
+    switch((guint)(app->data_valid_interval / 3600)){
+	case 1:  gtk_combo_box_set_active(GTK_COMBO_BOX(valid_time_list), 0);break;
+	default:
+	case 2:  gtk_combo_box_set_active(GTK_COMBO_BOX(valid_time_list), 1);break;
+	case 4:  gtk_combo_box_set_active(GTK_COMBO_BOX(valid_time_list), 2);break;
+	case 8:  gtk_combo_box_set_active(GTK_COMBO_BOX(valid_time_list), 3);break;
+    }
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_label_new(_("Updating of weather data:")),
+        			0, 1, 1, 2);
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
+        			1, 2, 1, 2);
     gtk_container_add(GTK_CONTAINER(label), update_time = gtk_combo_box_new_text());
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_label_new(_("Next update:")),
+        			0, 1, 2, 3);
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
+        			1, 2, 2, 3);
+    next_update_time = next_update();
+    if(!next_update_time)
+	temp_string = _("Never");
+    else{
+	tmp_buff[0] = 0;
+	strftime(tmp_buff, sizeof(tmp_buff) - 1, "%X %x", localtime(&next_update_time));
+	temp_string = tmp_buff;
+    }
+    gtk_container_add(GTK_CONTAINER(label), gtk_label_new(temp_string));
 /* Fill update time box */
     time_update_list_temp = time_update_list;
     while(time_update_list_temp != NULL){
@@ -962,6 +1021,15 @@ void weather_window_preference(GtkWidget *widget,
 	time_update_list_temp = g_slist_next(time_update_list_temp);
 	index_update_time++;
     }
+#ifdef PC_EMULATOR
+/* Evetns list tab */
+    memset(tmp_buff, 0, sizeof(tmp_buff));
+    print_list(tmp_buff, sizeof(tmp_buff) - 1);
+    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+        			create_scrolled_window_with_text(tmp_buff,
+						    GTK_JUSTIFY_LEFT),
+        			label = gtk_label_new(_("Events")));
+#endif
     gtk_widget_show_all(window_config);
 /* kill popup window :-) */
     if (app->popup_window){
@@ -1024,6 +1092,18 @@ void weather_window_preference(GtkWidget *widget,
 		    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(chk_transparency));
     		flag_update_icon = TRUE;
 	    }
+/* Split data mode */
+    	    if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(separate_button)) != app->separate){
+		app->separate = 
+		    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(separate_button));
+    		flag_update_icon = TRUE;
+	    }
+/* Swap temperature data mode */
+    	    if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(swap_temperature_button)) != app->swap_hi_low_temperature){
+		app->swap_hi_low_temperature = 
+		    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(swap_temperature_button));
+    		flag_update_icon = TRUE;
+	    }
 /* Distance units */
 	    if( gtk_combo_box_get_active((GtkComboBox*)units) != app->distance_units ){
 		app->distance_units = gtk_combo_box_get_active((GtkComboBox*)units);
@@ -1034,6 +1114,11 @@ void weather_window_preference(GtkWidget *widget,
 		app->wind_units = gtk_combo_box_get_active((GtkComboBox*)wunits);
     		flag_update_icon = TRUE;
 	    }
+/* Data valid time */
+	    if( (1 << gtk_combo_box_get_active((GtkComboBox*)valid_time_list)) != app->data_valid_interval / 3600 ){
+		app->data_valid_interval = 3600 * (1 << gtk_combo_box_get_active((GtkComboBox*)valid_time_list));
+    		flag_update_icon = TRUE;
+	    }
 /* Find select element of update time box and save time value */
 	    time_update_list_temp = time_update_list;
 	    while(time_update_list_temp){
@@ -1090,6 +1175,7 @@ void weather_window_preference(GtkWidget *widget,
 					_("Use Edit layout \nfor tuning images of applet"));
     gtk_widget_destroy(window_config);
 }
+/*******************************************************************************/
 /* get icon set names */
 void create_icon_set_list(GtkWidget *store){
     Dirent	*dp;
@@ -1122,7 +1208,7 @@ void create_icon_set_list(GtkWidget *store){
 	gtk_combo_box_set_active(GTK_COMBO_BOX(store), 0);
     }
 }
-
+/*******************************************************************************/
 void create_help_dialog(void){
     GtkWidget	*help_dialog,
 		*notebook,
@@ -1133,7 +1219,7 @@ void create_help_dialog(void){
     help_dialog = gtk_dialog_new_with_buttons(_("Other Maemo Weather Info"),
         				NULL,
 					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-        				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+        				_("OK"), GTK_RESPONSE_ACCEPT,
 					NULL);
 /* Create Notebook widget */
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(help_dialog)->vbox),
@@ -1170,21 +1256,32 @@ void create_help_dialog(void){
 	    "Greg Thompson for support stations.txt file\n"
 	    "Frank Persian - for idea of new layout\n"
 	    "Brian Knight - for idea of iconset, criticism \n"
-	    "\t\t\t\tand donation ;-)\n"
-	    "Andrew aka Tabster - for testing and ideas\n"
+	    "\t\t\t\tand donation ;-)\n"));
+    strcat(tmp_buff,	    
+	    _("Andrew aka Tabster - for testing and ideas\n"
 	    "Brad Jones aka kazrak - for testing\n"
+	    "Alexis Iglauer - for testing\n"
 	    "Eugene Roytenberg - for testing\n"
 	    "Jarek Szczepanski aka Imrahil - for testing\n"));
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         			create_scrolled_window_with_text(tmp_buff,
 						    GTK_JUSTIFY_LEFT),
         			title = gtk_label_new(_("Thanks")));
+/* Translators tab */
+    snprintf(tmp_buff, sizeof(tmp_buff), "%s",
+	    _("French - Nicolas Granziano\n"
+	      "Russian - Pavel Fialko, Vlad Vasiliev,\n\t    Ed Bartosh\n"));
+    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+        			create_scrolled_window_with_text(tmp_buff,
+						    GTK_JUSTIFY_LEFT),
+        			title = gtk_label_new(_("Translators")));
+
     gtk_widget_show_all(help_dialog);
 /* start dialog window */
     result = gtk_dialog_run(GTK_DIALOG(help_dialog));
     gtk_widget_destroy(help_dialog);
 }
-
+/*******************************************************************************/
 GtkWidget* create_scrolled_window_with_text(const char* text,
 				GtkJustification justification){
 
@@ -1214,7 +1311,7 @@ GtkWidget* create_scrolled_window_with_text(const char* text,
     gtk_container_add(GTK_CONTAINER(scrolled_window), GTK_WIDGET(text_view));
     return scrolled_window;
 }
-
+/*******************************************************************************/
 void station_list_view_select_handler(GtkTreeView *tree_view,
                                         gpointer user_data){
     struct weather_station *ws;
@@ -1251,3 +1348,4 @@ void station_list_view_select_handler(GtkTreeView *tree_view,
     weather_frame_update(TRUE);
     config_save_current_station();
 }
+/*******************************************************************************/
