@@ -221,7 +221,7 @@ GtkWidget* create_header_widget(int i){
 		*date_label;
     GtkIconInfo *gtkicon_update;
     gchar       buffer[1024];
-    struct tm	tmp_time_date_struct;
+    struct tm	tmp_time_date_struct = {0};
 
 /* Show full or short name station */ 
     if(i < DAY_DOWNLOAD){
@@ -258,6 +258,7 @@ GtkWidget* create_header_widget(int i){
     fprintf(stderr, "\nDate = %s Day name %s\n", weather_days[i].date,
                    weather_days[i].dayfuname);
 #endif
+	memset(buffer, 0, sizeof(buffer));
 	sprintf(buffer,"%s %s", weather_days[i].dayfuname, weather_days[i].date);
 	strptime(buffer, "%A %b %d", &tmp_time_date_struct);
 	memset(buffer, 0, sizeof(buffer));
@@ -328,7 +329,7 @@ GtkWidget* create_current_weather_widget(void){
 
 /* prepare current temperature */
     temperature_vbox = gtk_vbox_new(FALSE, 0);
-    buffer[0] = 0;
+    memset(buffer, 0, sizeof(buffer));
     strcat(buffer, _("Now: "));
     sprintf(buffer + strlen(buffer), "%d\302\260",
 		((app->temperature_units == CELSIUS) ? ( atoi(weather_current_day.day.temp))
@@ -341,7 +342,7 @@ GtkWidget* create_current_weather_widget(void){
     
 /* prepare "feels like", "visible", "pressure", "humidity", "wind", "gust" */
 /* feels like */
-    buffer[0] = 0;
+    memset(buffer, 0, sizeof(buffer));
     strcat(buffer, weather_current_day.day.title);
     strcat(buffer, _("\nFeels like: "));
     sprintf(buffer + strlen(buffer), "%d\302\260", 
@@ -444,7 +445,7 @@ GtkWidget* create_temperature_range_widget(int i){
     }
     if(app->swap_hi_low_temperature)
 	swap_temperature(&hi_temp, &low_temp);
-    buffer[0] = 0;
+    memset(buffer, 0, sizeof(buffer));
     /* prepare low temperature */
     if(low_temp == INT_MAX)
 	strncat(buffer, (char*)hash_table_find("N/A"),
@@ -483,12 +484,12 @@ GtkWidget* create_temperature_range_widget(int i){
 /*******************************************************************************/
 GtkWidget* create_24_hours_widget(int i, time_t current_time){
     GtkWidget	*main_widget,
-		*night_hbox,*day_hbox,
+		*night_hbox = NULL, *day_hbox = NULL,
 		*night_icon_label_vbox, *day_icon_label_vbox,
 		*night_icon, *day_icon,
 		*night_label, *day_label,
 		*night_data_label, *day_data_label,
-		*separator_after_night;
+		*separator_after_night = NULL;
     GdkPixbuf	*icon;
     gchar	buffer[1024];
     const gchar	*wind_units_str[] = { "m/s", "km/s", "mi/s", "m/h", "km/h", "mi/h" };
@@ -497,6 +498,12 @@ GtkWidget* create_24_hours_widget(int i, time_t current_time){
     int 	offset = 0 , j = 0;
     struct tm	*tm;
 
+#ifdef PC_EMULATOR
+    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
+#endif
+
+
+    memset(buffer, 0, sizeof(buffer));
 /* prepare additional time values */
     utc_time = mktime(gmtime(&current_time));
     if(i < Max_count_weather_day)
